@@ -18,7 +18,7 @@ def on_dag_failure_callback(context):
     conn_id = task.xcom_pull(key=CONNECTION_ID)
     pipeline_run_id = get_dag_run_pipeline_run_id(task)
     client = TorchDAGClient(conn_id)
-    pipeline_run = client.get_pipeline_run(pipeline_run_id)
+    pipeline_run = client.get_pipeline_run(pipeline_run_id=pipeline_run_id)
     parent_span = pipeline_run.get_root_span()
     parent_span.send_event(GenericEvent(context_data={'dag_status': 'FAILED', 'time': str(datetime.now())},
                                         event_uid=f'{parent_span.span.uid}.error.event'))
@@ -39,7 +39,7 @@ def on_dag_success_callback(context):
     conn_id = task.xcom_pull(key="CONNECTION_ID")
     pipeline_run_id = get_dag_run_pipeline_run_id(task)
     client = TorchDAGClient(conn_id)
-    pipeline_run = client.get_pipeline_run(pipeline_run_id)
+    pipeline_run = client.get_pipeline_run(pipeline_run_id=pipeline_run_id)
     parent_span = pipeline_run.get_root_span()
     parent_span.end(context_data={'dag_status': 'SUCCESS', 'time': str(datetime.now())})
     pipeline_run.update_pipeline_run(
